Library IEEE;
use IEEE.STD_LOGIC_1164.all;

entity counter_fsm is
port(	updown : in STD_LOGIC;
		clock : in STD_LOGIC;
		lsb : out STD_LOGIC;
		msb : out STD_LOGIC
);

end counter_fsm;

architecture counter_fsm of counter_fsm is
	type count_state is (zero, one, two, three);
	signal present_state, next_state : count_state;
	--attribute syn_encoding : string;
	--attribute syn_encoding of count_state : type is "11 01 10 00";
begin

process (present_state, updown)
begin
	case present_state is
		when zero =>
			if (updown = '0') then
				next_state <= one;
				lsb <= '0';
				msb <= '0';
			else
				next_state <= three;
				lsb <= '1';
				msb <= '1';
			end if;
			
		when one =>
			if (updown = '0') then
				next_state <= two;
				lsb <= '1';
				msb <= '0';
			else
				next_state <= zero;
				lsb <= '0';
				msb <= '0';
		end if;
		
		when two =>
			if (updown = '0') then
				next_state <= three;
				lsb <= '0';
				msb <= '1';
			else
				next_state <= one;
				lsb <= '1';
				msb <= '0';
			end if;
			
		when three =>
			if (updown = '0') then
				next_state <= zero;
				lsb <= '1';
				msb <= '1';
			else
				next_state <= two;
				lsb <= '0';
				msb <= '1';
			end if;
	end case;
end process;

process
begin
	wait until rising_edge(clock);
	present_state <= next_state;
end process;

end counter_fsm;

LIBRARY ieee  ; 
USE ieee.std_logic_1164.all  ; 
ENTITY counter_fsm_tb  IS 
END ; 
 
ARCHITECTURE counter_fsm_tb_arch OF counter_fsm_tb IS
  SIGNAL clock   :  std_logic  ; 
  SIGNAL lsb   :  std_logic  ; 
  SIGNAL updown   :  std_logic  ; 
  SIGNAL msb   :  std_logic  ; 
  COMPONENT counter_fsm  
    PORT ( 
      clock  : in std_logic ; 
      lsb  : out std_logic ; 
      updown  : in std_logic ; 
      msb  : out std_logic ); 
  END COMPONENT ; 
BEGIN
  DUT  : counter_fsm  
    PORT MAP ( 
      clock   => clock  ,
      lsb   => lsb  ,
      updown   => updown  ,
      msb   => msb   ) ; 
      
     ----- add here your clock loop and input ----------------
	 
         
   
      
END ; 